==> ovirt-engine-3.2.0.tar.gz: backend/manager/modules/dal/src/main/java/org/ovirt/engine/core/dao/DbUserDAO.java <==
package org.ovirt.engine.core.dao;

import java.util.List;
import java.util.Map;

import org.ovirt.engine.core.common.businessentities.DbUser;
import org.ovirt.engine.core.compat.Guid;
import org.ovirt.engine.core.dal.dbbroker.user_sessions;

/**
 * <code>DbUserDAO</code> defines a type for performing CRUD operations on instances of {@link DbUser}.
 *
 *
 */
public interface DbUserDAO extends DAO, SearchDAO<DbUser> {

    /**
     * Retrieves the suser with the specified id.
     *
     * @param id
     *            the id
     * @return the user, or <code>null</code> if the id was invalid
     */
    DbUser get(Guid id);

    /**
     * Retrieves a user by username.
     *
     * @param username
     *            the username
     * @return the user
     */
    DbUser getByUsername(String username);

    /**
     * Retrieves all users associated with the specified virtual machine.
     *
     * @param id
     *            the VM id
     * @return the list of users
     */
    List<DbUser> getAllForVm(Guid id);

    /**
     * Retrieves all users associated with the specified virtual machine id.
     *
     * @param vmid
     *            the virtual machine id
     * @return the list of users
     */
    List<DbUser> getAllTimeLeasedUsersForVm(int vmid);

    /**
     * Retrieves all defined used.
     *
     * @return the collection of all users
     */
    List<DbUser> getAll();

    /**
     * Retrieves all sessions.
     *
     * @return the list of sessions
     */
    List<user_sessions> getAllUserSessions();

    /**
     * Saves the user.
     *
     * @param user
     *            the user
     */
    void save(DbUser user);

    /**
     * Saves the specified user session. Admin users, though, are not saved.
     *
     * @param session
     *            the session
     */
    void saveSession(user_sessions session);

    /**
     * Updates the specified user in the database.
     *
     * @param user
     *            the user
     */
    void update(DbUser user);

    /**
     * Removes the user with the specified id.
     *
     * @param user
     *            the user id
     */
    void remove(Guid user);

    /**
     * Removes the specified session for the specified user.
     *
     * @param session
     *            the session
     * @param user
     *            the user
     */
    void removeUserSession(String session, Guid user);

    /**
     * Removes the specified user sessions.
     *
     * @param sessionmap
     *            the session map
     */
    void removeUserSessions(Map<String, Guid> sessionmap);

    /**
     * Removes all user sessions.
     */
    void removeAllSessions();
}

==> ovirt-engine-3.3.4.tar.gz: backend/manager/modules/dal/src/main/java/org/ovirt/engine/core/dao/DbUserDAO.java <==
package org.ovirt.engine.core.dao;

import java.util.List;

import org.ovirt.engine.core.common.businessentities.DbUser;
import org.ovirt.engine.core.compat.Guid;

/**
 * <code>DbUserDAO</code> defines a type for performing CRUD operations on instances of {@link DbUser}.
 *
 *
 */
public interface DbUserDAO extends DAO, SearchDAO<DbUser> {

    /**
     * Retrieves the suser with the specified id.
     *
     * @param id
     *            the id
     * @return the user, or <code>null</code> if the id was invalid
     */
    DbUser get(Guid id);

    /**
     * Retrieves a user by username.
     *
     * @param username
     *            the username
     * @return the user
     */
    DbUser getByUsername(String username);

    /**
     * Retrieves a user by domain name and external identifier.
     *
     * @param domain the name of the domain
     * @param externalId the external identifier
     * @return a reference to the user or <code>null</code> if no such user
     *   can be found in the database
     */
    DbUser getByExternalId(String domain, byte[] externalId);

    /**
     * Retrieves all users associated with the specified virtual machine.
     *
     * @param id
     *            the VM id
     * @return the list of users
     */
    List<DbUser> getAllForVm(Guid id);

    /**
     * Retrieves all defined used.
     *
     * @return the collection of all users
     */
    List<DbUser> getAll();

    /**
     * Retrieves all users
     *
     * @return the list of entries
     */
    List<DbUser> getAll(Guid userID, boolean isFiltered);

    /**
     * Saves the user.
     *
     * @param user
     *            the user
     */
    void save(DbUser user);

    /**
     * Updates the specified user in the database.
     *
     * @param user
     *            the user
     */
    void update(DbUser user);

    /**
     * Removes the user with the specified id.
     *
     * @param user
     *            the user id
     */
    void remove(Guid user);
}
